@@ -1,10 +1,9 @@
-import logging
-import os
-import requests
 from requests.adapters import HTTPAdapter
 from stream import exceptions, serializer
 from stream.signing import sign
-from stream.utils import validate_feed
+import logging
+import os
+import requests
 
 
 logger = logging.getLogger(__name__)
@@ -13,13 +12,13 @@ logger = logging.getLogger(__name__)
 class StreamClient(object):
     base_url = 'https://getstream.io/api/'
 
-    def __init__(self, api_key, api_secret, site_id, base_url=None):
+    def __init__(self, api_key, api_secret, app_id, version='v1.0', timeout=3.0, base_url=None):
         '''
         Initialize the client with the given api key and secret
 
         :param api_key: the api key
         :param api_secret: the api secret
-        :param base_url: (optionally overwrite the api base url)
+        :param app_id: the app id
 
         **Example usage**::
 
@@ -40,28 +39,33 @@ class StreamClient(object):
         '''
         self.api_key = api_key
         self.api_secret = api_secret
-        self.site_id = site_id
+        self.app_id = app_id
+        self.version = version
+        self.timeout = timeout
         if base_url is not None:
             self.base_url = base_url
         if os.environ.get('LOCAL'):
             self.base_url = 'http://localhost:8000/api/'
         self.session = requests.Session()
-        self.session.mount(self.base_url, HTTPAdapter(max_retries=3))
+        # TODO: turn this back on after we verify it doesnt retry on slower requests
+        self.session.mount(self.base_url, HTTPAdapter(max_retries=0))
 
-    def feed(self, feed_id):
+    def feed(self, feed_slug, user_id):
         '''
         Returns a Feed object
 
-        :param feed_id: the feed object
+        :param feed_slug: the slug of the feed
+        :param user_id: the user id
         '''
-        validate_feed(feed_id)
         from stream.feed import Feed
+        user_id = str(user_id)
+        feed_slug = str(feed_slug)
 
         # generate the token
-        feed_together = feed_id.replace(':', '')
-        token = sign(self.api_secret, feed_together)
+        feed_id = '%s%s' % (feed_slug, user_id)
+        token = sign(self.api_secret, feed_id)
 
-        return Feed(self, feed_id, token)
+        return Feed(self, feed_slug, user_id, token)
 
     def get_default_params(self):
         '''
@@ -70,45 +74,62 @@ class StreamClient(object):
         params = dict(api_key=self.api_key)
         return params
 
-    def _make_request(self, method, relative_url, authorization, params=None, data=None):
+    def get_full_url(self, relative_url):
+        url = self.base_url + self.version + '/' + relative_url
+        return url
+
+    def get_user_agent(self):
+        from stream import __version__
+        agent = 'stream-javascript-client-%s' % __version__
+        return agent
+
+    def _make_request(self, method, relative_url, signature, params=None, data=None):
         params = params or {}
         data = data or {}
-
         default_params = self.get_default_params()
         default_params.update(params)
-
-        headers = {'Authorization': authorization}
+        headers = {'Authorization': signature}
         headers['Content-type'] = 'application/json'
-
-        url = self.base_url + relative_url
-
+        headers['User-Agent'] = self.get_user_agent()
+        url = self.get_full_url(relative_url)
         serialized = serializer.dumps(data)
         response = method(url, data=serialized, headers=headers,
-                          params=default_params)
+                          params=default_params, timeout=self.timeout)
         logger.debug('stream api call %s, headers %s data %s',
                      response.url, headers, data)
-        result = serializer.loads(response.content)
-        if result.get('exception'):
-            self.raise_exception(result, status_code=response.status_code)
-        return result
+        try:
+            parsed_result = serializer.loads(response.text)
+        except ValueError:
+            parsed_result = None
+        if parsed_result.get('exception') or response.status_code >= 500:
+            self.raise_exception(parsed_result, status_code=response.status_code)
+        return parsed_result
 
     def raise_exception(self, result, status_code):
         '''
         Map the exception code to an exception class and raise it
+        If result.exception and result.detail are available use that
+        Otherwise just raise a generic error
         '''
         from stream.exceptions import get_exception_dict
-        error_message = result['detail']
-        exception_fields = result.get('exception_fields')
-        if exception_fields is not None:
-            errors = []
-            for field, errors in exception_fields.items():
-                errors.append('Field "%s" errors: %s' %
-                              (field, repr(errors)))
-            error_message = '\n'.join(errors)
-        error_code = result.get('code')
-        exception_dict = get_exception_dict()
-        exception_class = exception_dict.get(
-            error_code, exceptions.StreamApiException)
+        exception_class = exceptions.StreamApiException
+        
+        if result is not None:
+            error_message = result['detail']
+            exception_fields = result.get('exception_fields')
+            if exception_fields is not None:
+                errors = []
+                for field, errors in exception_fields.items():
+                    errors.append('Field "%s" errors: %s' %
+                                  (field, repr(errors)))
+                error_message = '\n'.join(errors)
+            error_code = result.get('code')
+            exception_dict = get_exception_dict()
+            exception_class = exception_dict.get(
+                error_code, exceptions.StreamApiException)
+        else:
+            error_message = 'GetStreamAPI%s' % status_code
+            
         exception = exception_class(error_message, status_code=status_code)
         raise exception
 
