@@ -16,13 +16,22 @@ def connect_debug():
         u'gthc2t9gh7pzq52f6cky8w4r4up9dr6rju9w3fjgmkv6cdvvav2ufe5fv7e2r9qy'
     )
 
+random_postfix = str(random.randint(0, 1000000))
 client = connect_debug()
-user1 = client.feed('user:1')
-user2 = client.feed('user:2')
-aggregated2 = client.feed('aggregated:2')
-aggregated3 = client.feed('aggregated:3')
-topic1 = client.feed('topic:1')
-flat3 = client.feed('flat:3')
+
+
+def getfeed(feed_slug, user_id):
+    '''
+    Adds the random postfix to the user id
+    '''
+    return client.feed(feed_slug, user_id + random_postfix)
+
+user1 = getfeed('user', '1')
+user2 = getfeed('user', '2')
+aggregated2 = getfeed('aggregated', '2')
+aggregated3 = getfeed('aggregated', '3')
+topic1 = getfeed('topic', '1')
+flat3 = getfeed('flat', '3')
 
 
 class ClientTest(TestCase):
@@ -38,34 +47,35 @@ class ClientTest(TestCase):
         self.flat3 = flat3
 
     def test_heroku(self):
-        url = 'https://thierry:pass@getstream.io/?site=1'
+        url = 'https://thierry:pass@getstream.io/?app_id=1'
         os.environ['STREAM_URL'] = url
         client = stream.connect()
         self.assertEqual(client.api_key, 'thierry')
         self.assertEqual(client.api_secret, 'pass')
-        self.assertEqual(client.site_id, '1')
-        
+        self.assertEqual(client.app_id, '1')
+
     def test_heroku_real(self):
-        url = 'https://bvt88g4kvc63:twc5ywfste5bm2ngqkzs7ukxk3pn96yweghjrxcmcrarnt3j4dqj3tucbhym5wfd@getstream.io/?site=669'
+        url = 'https://bvt88g4kvc63:twc5ywfste5bm2ngqkzs7ukxk3pn96yweghjrxcmcrarnt3j4dqj3tucbhym5wfd@getstream.io/?app_id=669'
         os.environ['STREAM_URL'] = url
         client = stream.connect()
         self.assertEqual(client.api_key, 'bvt88g4kvc63')
-        self.assertEqual(client.api_secret, 'twc5ywfste5bm2ngqkzs7ukxk3pn96yweghjrxcmcrarnt3j4dqj3tucbhym5wfd')
-        self.assertEqual(client.site_id, '669')
+        self.assertEqual(
+            client.api_secret, 'twc5ywfste5bm2ngqkzs7ukxk3pn96yweghjrxcmcrarnt3j4dqj3tucbhym5wfd')
+        self.assertEqual(client.app_id, '669')
 
     def test_heroku_overwrite(self):
-        url = 'https://thierry:pass@getstream.io/?site=1'
+        url = 'https://thierry:pass@getstream.io/?app_id=1'
         os.environ['STREAM_URL'] = url
         client = stream.connect('a', 'b', 'c')
         self.assertEqual(client.api_key, 'a')
         self.assertEqual(client.api_secret, 'b')
-        self.assertEqual(client.site_id, 'c')
+        self.assertEqual(client.app_id, 'c')
 
     def test_token_retrieval(self):
         self.user1.token
 
     def test_add_activity(self):
-        feed = client.feed('user:py1')
+        feed = getfeed('user', 'py1')
         activity_data = {'actor': 1, 'verb': 'tweet', 'object': 1}
         response = feed.add_activity(activity_data)
         activity_id = response['id']
@@ -75,10 +85,10 @@ class ClientTest(TestCase):
     def test_add_activity_to(self):
         activity_data = {
             'actor': 1, 'verb': 'tweet', 'object': 1,
-            'to': ['user:pyto1']
+            'to': [getfeed('user', 'pyto1').id]
         }
         response = self.user1.add_activity(activity_data)
-        feed = client.feed('user:pyto1')
+        feed = getfeed('user', 'pyto1')
         activity_id = response['id']
         activities = feed.get(limit=1)['results']
         self.assertEqual(activities[0]['id'], activity_id)
@@ -112,7 +122,7 @@ class ClientTest(TestCase):
         self.assertEqual(get_activity_ids, activity_ids[::-1])
 
     def test_add_activities_to(self):
-        to = ['user:pyto2', 'user:pyto3']
+        to = [getfeed('user', 'pyto2').id, getfeed('user', 'pyto3').id]
         activity_data = [
             {'actor': 1, 'verb': 'tweet', 'object': 1, 'to': to},
             {'actor': 2, 'verb': 'watch', 'object': 2, 'to': to},
@@ -123,23 +133,23 @@ class ClientTest(TestCase):
         get_activity_ids = [a['id'] for a in activities]
         self.assertEqual(get_activity_ids, activity_ids[::-1])
         # test first target
-        feed = client.feed('user:pyto2')
+        feed = getfeed('user', 'pyto2')
         activities = feed.get(limit=2)['results']
         get_activity_ids = [a['id'] for a in activities]
         self.assertEqual(get_activity_ids, activity_ids[::-1])
         # test second target
-        feed = client.feed('user:pyto3')
+        feed = getfeed('user', 'pyto3')
         activities = feed.get(limit=2)['results']
         get_activity_ids = [a['id'] for a in activities]
         self.assertEqual(get_activity_ids, activity_ids[::-1])
 
     def test_follow(self):
-        feed = client.feed('user:test_follow')
-        agg_feed = client.feed('aggregated:test_follow')
+        feed = getfeed('user', 'test_follow')
+        agg_feed = getfeed('aggregated', 'test_follow')
         actor_id = random.randint(10, 100000)
         activity_data = {'actor': actor_id, 'verb': 'tweet', 'object': 1}
         activity_id = feed.add_activity(activity_data)['id']
-        agg_feed.follow('user:test_follow')
+        agg_feed.follow(feed.slug, feed.user_id)
         time.sleep(10)
         activities = agg_feed.get(limit=3)['results']
         activity = self._get_first_aggregated_activity(activities)
@@ -147,12 +157,12 @@ class ClientTest(TestCase):
         self.assertEqual(activity_id_found, activity_id)
 
     def test_follow_private(self):
-        feed = client.feed('secret:py1')
-        agg_feed = client.feed('aggregated:test_follow_private')
+        feed = getfeed('secret', 'py1')
+        agg_feed = getfeed('aggregated', 'test_follow_private')
         actor_id = random.randint(10, 100000)
         activity_data = {'actor': actor_id, 'verb': 'tweet', 'object': 1}
         activity_id = feed.add_activity(activity_data)['id']
-        agg_feed.follow('secret:py1')
+        agg_feed.follow(feed.slug, feed.user_id)
         time.sleep(10)
         activities = agg_feed.get(limit=3)['results']
         activity = self._get_first_aggregated_activity(activities)
@@ -160,10 +170,10 @@ class ClientTest(TestCase):
         self.assertEqual(activity_id_found, activity_id)
 
     def test_flat_follow(self):
-        feed = client.feed('user:test_flat_follow')
+        feed = getfeed('user', 'test_flat_follow')
         activity_data = {'actor': 1, 'verb': 'tweet', 'object': 1}
         activity_id = feed.add_activity(activity_data)['id']
-        self.flat3.follow('user:test_flat_follow')
+        self.flat3.follow(feed.slug, feed.user_id)
         time.sleep(10)
         activities = self.flat3.get(limit=3)['results']
         activity = self._get_first_activity(activities)
@@ -185,8 +195,8 @@ class ClientTest(TestCase):
     def test_unfollow(self):
         activity_data = {'actor': 1, 'verb': 'tweet', 'object': 1}
         activity_id = self.user1.add_activity(activity_data)['id']
-        self.aggregated3.follow('user:1')
-        self.aggregated3.unfollow('user:1')
+        self.aggregated3.follow('user', '1')
+        self.aggregated3.unfollow('user', '1')
         time.sleep(5)
         activities = self.aggregated3.get(limit=3)['results']
         activity = self._get_first_aggregated_activity(activities)
@@ -194,59 +204,61 @@ class ClientTest(TestCase):
         self.assertNotEqual(activity_id_found, activity_id)
 
     def test_empty_followings(self):
-        asocial = client.feed('user:asocialpython')
+        asocial = getfeed('user', 'asocialpython')
         followings = asocial.following()
         self.assertEqual(followings['results'], [])
 
     def test_get_followings(self):
-        social = client.feed('user:psocial')
-        social.follow('user:apy')
-        social.follow('user:bpy')
-        social.follow('user:cpy')
+        social = getfeed('user', 'psocial')
+        social.follow('user', 'apy')
+        social.follow('user', 'bpy')
+        social.follow('user', 'cpy')
         followings = social.following(offset=0, limit=2)
         self.assertEqual(len(followings['results']), 2)
-        self.assertEqual(followings['results'][0]['feed_id'], 'user:psocial')
+        self.assertEqual(followings['results'][0]['feed_id'], social.id)
         self.assertEqual(followings['results'][0]['target_id'], 'user:cpy')
         followings = social.following(offset=1, limit=2)
         self.assertEqual(len(followings['results']), 2)
-        self.assertEqual(followings['results'][0]['feed_id'], 'user:psocial')
+        self.assertEqual(followings['results'][0]['feed_id'], social.id)
         self.assertEqual(followings['results'][0]['target_id'], 'user:bpy')
 
     def test_empty_followers(self):
-        asocial = client.feed('user:asocialpython')
+        asocial = getfeed('user', 'asocialpython')
         followers = asocial.followers()
         self.assertEqual(len(followers['results']), 0)
         self.assertEqual(followers['results'], [])
 
     def test_get_followers(self):
-        social = client.feed('user:psocial')
-        client.feed('user:spammy1').follow('user:psocial')
-        client.feed('user:spammy2').follow('user:psocial')
-        client.feed('user:spammy3').follow('user:psocial')
+        social = getfeed('user', 'psocial')
+        spammy1 = getfeed('user', 'spammy1')
+        spammy2 = getfeed('user', 'spammy2')
+        spammy3 = getfeed('user', 'spammy3')
+        for feed in [spammy1, spammy2, spammy3]:
+            feed.follow('user', social.user_id)
         followers = social.followers(offset=0, limit=2)
         self.assertEqual(len(followers['results']), 2)
-        self.assertEqual(followers['results'][0]['feed_id'], 'user:spammy3')
-        self.assertEqual(followers['results'][0]['target_id'], 'user:psocial')
+        self.assertEqual(followers['results'][0]['feed_id'], spammy3.id)
+        self.assertEqual(followers['results'][0]['target_id'], social.id)
         followers = social.followers(offset=1, limit=2)
         self.assertEqual(len(followers['results']), 2)
-        self.assertEqual(followers['results'][0]['feed_id'], 'user:spammy2')
-        self.assertEqual(followers['results'][0]['target_id'], 'user:psocial')
+        self.assertEqual(followers['results'][0]['feed_id'], spammy2.id)
+        self.assertEqual(followers['results'][0]['target_id'], social.id)
 
     def test_empty_do_i_follow(self):
-        social = client.feed('user:psocial')
-        social.follow('user:apy')
-        social.follow('user:bpy')
+        social = getfeed('user', 'psocial')
+        social.follow('user', 'apy')
+        social.follow('user', 'bpy')
         followings = social.following(feeds=['user:missingpy'])
         self.assertEqual(len(followings['results']), 0)
         self.assertEqual(followings['results'], [])
 
     def test_do_i_follow(self):
-        social = client.feed('user:psocial')
-        social.follow('user:apy')
-        social.follow('user:bpy')
+        social = getfeed('user', 'psocial')
+        social.follow('user', 'apy')
+        social.follow('user', 'bpy')
         followings = social.following(feeds=['user:apy'])
         self.assertEqual(len(followings['results']), 1)
-        self.assertEqual(followings['results'][0]['feed_id'], 'user:psocial')
+        self.assertEqual(followings['results'][0]['feed_id'], social.id)
         self.assertEqual(followings['results'][0]['target_id'], 'user:apy')
 
     def test_get(self):
@@ -269,7 +281,7 @@ class ClientTest(TestCase):
         self.assertEqual(activities[0]['id'], activity_id)
 
     def test_mark_read(self):
-        notification_feed = client.feed('notification:py3')
+        notification_feed = getfeed('notification', 'py3')
         activity_data = {'actor': 1, 'verb': 'tweet', 'object': 1}
         notification_feed.add_activity(activity_data)
         activity_data = {'actor': 2, 'verb': 'add', 'object': 2}
@@ -285,7 +297,7 @@ class ClientTest(TestCase):
             self.assertTrue(activity['is_read'])
 
     def test_mark_read_by_id(self):
-        notification_feed = client.feed('notification:py2')
+        notification_feed = getfeed('notification', 'py2')
         activity_data = {'actor': 1, 'verb': 'tweet', 'object': 1}
         notification_feed.add_activity(activity_data)['id']
         activity_data = {'actor': 2, 'verb': 'add', 'object': 2}
@@ -309,7 +321,7 @@ class ClientTest(TestCase):
             '5crf3bhfzesnMISSING',
             'tfq2sdqpj9g446sbv653x3aqmgn33hsn8uzdc9jpskaw8mj6vsnhzswuwptuj9su'
         )
-        self.user1 = self.c.feed('user:1')
+        self.user1 = self.c.feed('user', '1')
         activity_data = {'actor': 1, 'verb': 'tweet',
                          'object': 1, 'debug_example_undefined': 'test'}
         self.assertRaises(ApiKeyException, lambda:
@@ -340,6 +352,7 @@ class ClientTest(TestCase):
         a.) The same time and activity data
         b.) The same time and foreign id
         '''
+        from pprint import pprint
         utcnow = datetime.datetime.utcnow()
         activity_data = {
             'actor': 1, 'verb': 'tweet', 'object': 1, 'time': utcnow}
@@ -347,7 +360,8 @@ class ClientTest(TestCase):
         response = self.user1.add_activity(activity_data)
         activities = self.user1.get(limit=2)['results']
         self.assertDatetimeAlmostEqual(activities[0]['time'], utcnow)
-        self.assertClearlyNotEqual(activities[1]['time'], utcnow)
+        if (len(activities) > 1):
+            self.assertClearlyNotEqual(activities[1]['time'], utcnow)
 
     def test_uniqueness_topic(self):
         '''
@@ -356,11 +370,11 @@ class ClientTest(TestCase):
         b.) The same time and foreign id
         '''
         # follow both the topic and the user
-        self.flat3.follow('topic:1')
-        self.flat3.follow('user:1')
+        self.flat3.follow('topic', self.topic1.user_id)
+        self.flat3.follow('user', self.user1.user_id)
         # add the same activity twice
         now = datetime.datetime.now(tzlocal())
-        tweet = 'My Way %s' % random.randint(10, 100000)
+        tweet = 'My Way %s' % random_postfix
         activity_data = {
             'actor': 1, 'verb': 'tweet', 'object': 1, 'time': now, 'tweet': tweet}
         self.topic1.add_activity(activity_data)
@@ -386,7 +400,7 @@ class ClientTest(TestCase):
         self.assertEqual(activities[0]['foreign_id'], 'tweet:11')
         self.assertDatetimeAlmostEqual(activities[0]['time'], utcnow)
         self.assertNotEqual(activities[1]['foreign_id'], 'tweet:11')
-        
+
     def test_time_ordering(self):
         '''
         datetime.datetime.utcnow() is our recommended approach
@@ -428,7 +442,7 @@ class ClientTest(TestCase):
             '5crf3bhfzesnMISSING',
             'tfq2sdqpj9g446sbv653x3aqmgn33hsn8uzdc9jpskaw8mj6vsnhzswuwptuj9su'
         )
-        self.assertRaises(ValueError, lambda: self.c.feed('user1'))
+        self.assertRaises(TypeError, lambda: getfeed('user1'))
 
     def test_serialization(self):
         today = datetime.date.today()
